API Reference
=============

.. automodule:: sybil
  :members: Sybil, Region

.. automodule:: sybil.document
  :members:

.. automodule:: sybil.example
  :members:

.. automodule:: sybil.parsers.doctest
  :members:

.. automodule:: sybil.parsers.codeblock
  :members:

.. automodule:: sybil.parsers.capture
  :members:

.. automodule:: sybil.parsers.skip
  :members:
